@@ -601,9 +601,9 @@ class CGIRequest(Request):
         
         self.server = server
         self.params = dict(os.environ)
-        self.stdin = sys.stdin
+        self.stdin = sys.stdin.buffer
         self.stdout = StdoutWrapper(sys.stdout.buffer) # Oh, the humanity!
-        self.stderr = sys.stderr
+        self.stderr = sys.stderr.buffer
         self.data = BytesIO()
         
     def _end(self, appStatus=0, protocolStatus=FCGI_REQUEST_COMPLETE):
